|Pergola web server|
====================

.. figure:: https://circleci.com/gh/cbcrg/pergola.png?style=shield
   :alt: CircleCI status

   CircleCI status

A python library for the conversion of behavioral data into genome
browser compatible formats. Once behavioral data is formatted in genomic
formats it is easy to use genomic software tools for its analysis. For
instance you can query your data using BEDTools or visualize your
records using a genome browser (see snapshot below corresponding to a
rendering of mice feeding behavior on the
`IGV <http://software.broadinstitute.org/software/igv/>`__ genome
browser).

For more information, instructions for installation and tutorials please
visit:

`Pergola documentation <http://cbcrg.github.io/pergola/>`__

You can also use our web server still under development:

`Pergola web server <http://pergola.crg.eu/>`__

.. figure:: https://github.com/cbcrg/pergola/blob/master/doc/source/images/mouse_hf_igv.png
   :alt: Mouse feeding behavior-IGV snapshot

   Mouse feeding behavior-IGV snapshot

.. |Pergola web server| image:: https://cloud.githubusercontent.com/assets/6224346/12887167/dcf80b24-ce72-11e5-8389-90122fd6c84e.png

